### introdutiom of samma tool

samma tool was design by the thought of pipeline of nlp
task and is inspired by the structure of keras. It is made up by
dataPorcess, models, metrics, loss, callback, tools and related package.


## dataProcess
    dataProcess pack contains related data processor tool, such as
    data transformer , data clean and data analyse
## models
    it contains related pretrain_embbedding and layers 
## metrics
    it contains realted metrics of nlp class such as acc, recall ,
    f1_score...
## callback
    
    it contains some useful hook of model training.
    
## tools
    it contains some realted tool in nlp.

 